from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Slist:
	"""Slist commands group definition. 7 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("slist", core, parent)

	@property
	def ports(self):
		"""ports commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ports'):
			from .Ports import Ports
			self._ports = Ports(self._core, self._base)
		return self._ports

	def get_catalog(self) -> str:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:CATalog \n
		Snippet: value: str = driver.source.correction.fresponse.rf.user.slist.get_catalog() \n
		Queries the S-parameter files included in the current S-paramters list. \n
			:return: catalog: filename1,filename2,...filename10 Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:CATalog?')
		return trim_str_response(response)

	def clear(self) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:CLEar \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.clear() \n
		Deletes all entries in the lists. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:CLEar')

	def clear_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:CLEar \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.clear_with_opc() \n
		Deletes all entries in the lists. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:CLEar')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:SELect \n
		Snippet: value: str = driver.source.correction.fresponse.rf.user.slist.get_select() \n
		Selects an existing S-parameter file (*.s<n>p) from the default directory or from the specific directory.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: freq_resp_rf_slsel: string Filename incl. file extension or complete file path Use 'none' to unload a file.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:SELect?')
		return trim_str_response(response)

	def set_select(self, freq_resp_rf_slsel: str) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:SELect \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.set_select(freq_resp_rf_slsel = '1') \n
		Selects an existing S-parameter file (*.s<n>p) from the default directory or from the specific directory.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param freq_resp_rf_slsel: string Filename incl. file extension or complete file path Use 'none' to unload a file.
		"""
		param = Conversions.value_to_quoted_str(freq_resp_rf_slsel)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:SELect {param}')

	def get_size(self) -> int:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:SIZE \n
		Snippet: value: int = driver.source.correction.fresponse.rf.user.slist.get_size() \n
		Queries the number of files in the list. \n
			:return: freq_resp_rf_sli_si: integer Range: 0 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:SIZE?')
		return Conversions.str_to_int(response)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:[STATe] \n
		Snippet: value: bool = driver.source.correction.fresponse.rf.user.slist.get_state() \n
		Enables that the selected file is used for frequency response compensation. To trigger calculation of the correction
		values, send the command [:SOURce<hw>]:CORRection:FRESponse:RF:USER:APPLy. Otherwise changes are not considered. \n
			:return: freq_resp_sli_stat: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, freq_resp_sli_stat: bool) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:RF:USER:SLISt:[STATe] \n
		Snippet: driver.source.correction.fresponse.rf.user.slist.set_state(freq_resp_sli_stat = False) \n
		Enables that the selected file is used for frequency response compensation. To trigger calculation of the correction
		values, send the command [:SOURce<hw>]:CORRection:FRESponse:RF:USER:APPLy. Otherwise changes are not considered. \n
			:param freq_resp_sli_stat: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(freq_resp_sli_stat)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:RF:USER:SLISt:STATe {param}')

	def clone(self) -> 'Slist':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Slist(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pusch:
	"""Pusch commands group definition. 7 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pusch", core, parent)

	@property
	def ccoding(self):
		"""ccoding commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import Ccoding
			self._ccoding = Ccoding(self._core, self._base)
		return self._ccoding

	@property
	def harq(self):
		"""harq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import Harq
			self._harq = Harq(self._core, self._base)
		return self._harq

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import Modulation
			self._modulation = Modulation(self._core, self._base)
		return self._modulation

	@property
	def physBits(self):
		"""physBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_physBits'):
			from .PhysBits import PhysBits
			self._physBits = PhysBits(self._core, self._base)
		return self._physBits

	@property
	def ri(self):
		"""ri commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ri'):
			from .Ri import Ri
			self._ri = Ri(self._core, self._base)
		return self._ri

	@property
	def ulsch(self):
		"""ulsch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ulsch'):
			from .Ulsch import Ulsch
			self._ulsch = Ulsch(self._core, self._base)
		return self._ulsch

	def clone(self) -> 'Pusch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pusch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Combined:
	"""Combined commands group definition. 4 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("combined", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	def clone(self) -> 'Combined':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Combined(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LogNormal:
	"""LogNormal commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("logNormal", core, parent)

	def get_cstd(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:COUPle:LOGNormal:CSTD \n
		Snippet: value: bool = driver.source.fsimulator.couple.logNormal.get_cstd() \n
		(available in 'System Configuration > Mode > Standard') Couples the lognormal fading setting. \n
			:return: cstd: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:COUPle:LOGNormal:CSTD?')
		return Conversions.str_to_bool(response)

	def set_cstd(self, cstd: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:COUPle:LOGNormal:CSTD \n
		Snippet: driver.source.fsimulator.couple.logNormal.set_cstd(cstd = False) \n
		(available in 'System Configuration > Mode > Standard') Couples the lognormal fading setting. \n
			:param cstd: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(cstd)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:COUPle:LOGNormal:CSTD {param}')

	def get_lconstant(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:COUPle:LOGNormal:LCONstant \n
		Snippet: value: bool = driver.source.fsimulator.couple.logNormal.get_lconstant() \n
		(available in 'System Configuration > Mode > Standard') Couples the lognormal fading setting. \n
			:return: lconstant: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:COUPle:LOGNormal:LCONstant?')
		return Conversions.str_to_bool(response)

	def set_lconstant(self, lconstant: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:COUPle:LOGNormal:LCONstant \n
		Snippet: driver.source.fsimulator.couple.logNormal.set_lconstant(lconstant = False) \n
		(available in 'System Configuration > Mode > Standard') Couples the lognormal fading setting. \n
			:param lconstant: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(lconstant)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:COUPle:LOGNormal:LCONstant {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TfConfig:
	"""TfConfig commands group definition. 26 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tfConfig", core, parent)

	@property
	def cinfo(self):
		"""cinfo commands group. 16 Sub-classes, 0 commands."""
		if not hasattr(self, '_cinfo'):
			from .Cinfo import Cinfo
			self._cinfo = Cinfo(self._core, self._base)
		return self._cinfo

	@property
	def nuInfo(self):
		"""nuInfo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nuInfo'):
			from .NuInfo import NuInfo
			self._nuInfo = NuInfo(self._core, self._base)
		return self._nuInfo

	@property
	def uinfo(self):
		"""uinfo commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_uinfo'):
			from .Uinfo import Uinfo
			self._uinfo = Uinfo(self._core, self._base)
		return self._uinfo

	def clone(self) -> 'TfConfig':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TfConfig(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	def get_start(self) -> float:
		"""SCPI: [SOURce<HW>]:COMBined:FREQuency:STARt \n
		Snippet: value: float = driver.source.combined.frequency.get_start() \n
		Sets the start frequency of the combined RF frequency / level sweep. See 'Correlating Parameters in Sweep Mode'. \n
			:return: comb_freq_start: float Range: -59999E5 to 12E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:COMBined:FREQuency:STARt?')
		return Conversions.str_to_float(response)

	def set_start(self, comb_freq_start: float) -> None:
		"""SCPI: [SOURce<HW>]:COMBined:FREQuency:STARt \n
		Snippet: driver.source.combined.frequency.set_start(comb_freq_start = 1.0) \n
		Sets the start frequency of the combined RF frequency / level sweep. See 'Correlating Parameters in Sweep Mode'. \n
			:param comb_freq_start: float Range: -59999E5 to 12E9
		"""
		param = Conversions.decimal_value_to_str(comb_freq_start)
		self._core.io.write(f'SOURce<HwInstance>:COMBined:FREQuency:STARt {param}')

	def get_stop(self) -> float:
		"""SCPI: [SOURce<HW>]:COMBined:FREQuency:STOP \n
		Snippet: value: float = driver.source.combined.frequency.get_stop() \n
		Sets the end frequency of the combined RF frequency / level sweep. \n
			:return: comb_freq_stop: float Range: -59999E5 to 12E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:COMBined:FREQuency:STOP?')
		return Conversions.str_to_float(response)

	def set_stop(self, comb_freq_stop: float) -> None:
		"""SCPI: [SOURce<HW>]:COMBined:FREQuency:STOP \n
		Snippet: driver.source.combined.frequency.set_stop(comb_freq_stop = 1.0) \n
		Sets the end frequency of the combined RF frequency / level sweep. \n
			:param comb_freq_stop: float Range: -59999E5 to 12E9
		"""
		param = Conversions.decimal_value_to_str(comb_freq_stop)
		self._core.io.write(f'SOURce<HwInstance>:COMBined:FREQuency:STOP {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NrUnits:
	"""NrUnits commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nrUnits", core, parent)

	def set(self, resource_units: enums.EutraIotRu, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:NIOT:TRANs<CH>:NRUNits \n
		Snippet: driver.source.bb.eutra.uplink.ue.niot.trans.nrUnits.set(resource_units = enums.EutraIotRu.RU1, userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		Sets the number of allocated resource units. \n
			:param resource_units: RU1| RU2| RU3| RU4| RU5| RU6| RU8| RU10
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')"""
		param = Conversions.enum_scalar_to_str(resource_units, enums.EutraIotRu)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._base.get_repcap_cmd_value(transmission, repcap.Transmission)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:NIOT:TRANs{transmission_cmd_val}:NRUNits {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> enums.EutraIotRu:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:NIOT:TRANs<CH>:NRUNits \n
		Snippet: value: enums.EutraIotRu = driver.source.bb.eutra.uplink.ue.niot.trans.nrUnits.get(userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		Sets the number of allocated resource units. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')
			:return: resource_units: RU1| RU2| RU3| RU4| RU5| RU6| RU8| RU10"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._base.get_repcap_cmd_value(transmission, repcap.Transmission)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:NIOT:TRANs{transmission_cmd_val}:NRUNits?')
		return Conversions.str_to_scalar_enum(response, enums.EutraIotRu)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frc:
	"""Frc commands group definition. 8 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frc", core, parent)

	@property
	def alrb(self):
		"""alrb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alrb'):
			from .Alrb import Alrb
			self._alrb = Alrb(self._core, self._base)
		return self._alrb

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import Modulation
			self._modulation = Modulation(self._core, self._base)
		return self._modulation

	@property
	def n2Dmrs(self):
		"""n2Dmrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_n2Dmrs'):
			from .N2Dmrs import N2Dmrs
			self._n2Dmrs = N2Dmrs(self._core, self._base)
		return self._n2Dmrs

	@property
	def paSize(self):
		"""paSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_paSize'):
			from .PaSize import PaSize
			self._paSize = PaSize(self._core, self._base)
		return self._paSize

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def tnoBits(self):
		"""tnoBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tnoBits'):
			from .TnoBits import TnoBits
			self._tnoBits = TnoBits(self._core, self._base)
		return self._tnoBits

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePy
			self._typePy = TypePy(self._core, self._base)
		return self._typePy

	@property
	def vrbOffset(self):
		"""vrbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vrbOffset'):
			from .VrbOffset import VrbOffset
			self._vrbOffset = VrbOffset(self._core, self._base)
		return self._vrbOffset

	def clone(self) -> 'Frc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdsch:
	"""Pdsch commands group definition. 25 total commands, 11 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pdsch", core, parent)

	@property
	def bmaid(self):
		"""bmaid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bmaid'):
			from .Bmaid import Bmaid
			self._bmaid = Bmaid(self._core, self._base)
		return self._bmaid

	@property
	def dmr(self):
		"""dmr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dmr'):
			from .Dmr import Dmr
			self._dmr = Dmr(self._core, self._base)
		return self._dmr

	@property
	def dmrs(self):
		"""dmrs commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmrs'):
			from .Dmrs import Dmrs
			self._dmrs = Dmrs(self._core, self._base)
		return self._dmrs

	@property
	def ncw(self):
		"""ncw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncw'):
			from .Ncw import Ncw
			self._ncw = Ncw(self._core, self._base)
		return self._ncw

	@property
	def patgrp(self):
		"""patgrp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_patgrp'):
			from .Patgrp import Patgrp
			self._patgrp = Patgrp(self._core, self._base)
		return self._patgrp

	@property
	def precg(self):
		"""precg commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_precg'):
			from .Precg import Precg
			self._precg = Precg(self._core, self._base)
		return self._precg

	@property
	def ptrs(self):
		"""ptrs commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ptrs'):
			from .Ptrs import Ptrs
			self._ptrs = Ptrs(self._core, self._base)
		return self._ptrs

	@property
	def resAlloc(self):
		"""resAlloc commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_resAlloc'):
			from .ResAlloc import ResAlloc
			self._resAlloc = ResAlloc(self._core, self._base)
		return self._resAlloc

	@property
	def sbcZero(self):
		"""sbcZero commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sbcZero'):
			from .SbcZero import SbcZero
			self._sbcZero = SbcZero(self._core, self._base)
		return self._sbcZero

	@property
	def txScheme(self):
		"""txScheme commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_txScheme'):
			from .TxScheme import TxScheme
			self._txScheme = TxScheme(self._core, self._base)
		return self._txScheme

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePy
			self._typePy = TypePy(self._core, self._base)
		return self._typePy

	def clone(self) -> 'Pdsch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pdsch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pusch:
	"""Pusch commands group definition. 77 total commands, 29 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pusch", core, parent)

	@property
	def accList(self):
		"""accList commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_accList'):
			from .AccList import AccList
			self._accList = AccList(self._core, self._base)
		return self._accList

	@property
	def apPresent(self):
		"""apPresent commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_apPresent'):
			from .ApPresent import ApPresent
			self._apPresent = ApPresent(self._core, self._base)
		return self._apPresent

	@property
	def bharq(self):
		"""bharq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bharq'):
			from .Bharq import Bharq
			self._bharq = Bharq(self._core, self._base)
		return self._bharq

	@property
	def brv(self):
		"""brv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_brv'):
			from .Brv import Brv
			self._brv = Brv(self._core, self._base)
		return self._brv

	@property
	def cbSubset(self):
		"""cbSubset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbSubset'):
			from .CbSubset import CbSubset
			self._cbSubset = CbSubset(self._core, self._base)
		return self._cbSubset

	@property
	def dmta(self):
		"""dmta commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmta'):
			from .Dmta import Dmta
			self._dmta = Dmta(self._core, self._base)
		return self._dmta

	@property
	def dmtb(self):
		"""dmtb commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_dmtb'):
			from .Dmtb import Dmtb
			self._dmtb = Dmtb(self._core, self._base)
		return self._dmtb

	@property
	def dsid(self):
		"""dsid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsid'):
			from .Dsid import Dsid
			self._dsid = Dsid(self._core, self._base)
		return self._dsid

	@property
	def dsInit(self):
		"""dsInit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dsInit'):
			from .DsInit import DsInit
			self._dsInit = DsInit(self._core, self._base)
		return self._dsInit

	@property
	def fhOffsets(self):
		"""fhOffsets commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fhOffsets'):
			from .FhOffsets import FhOffsets
			self._fhOffsets = FhOffsets(self._core, self._base)
		return self._fhOffsets

	@property
	def fhop(self):
		"""fhop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fhop'):
			from .Fhop import Fhop
			self._fhop = Fhop(self._core, self._base)
		return self._fhop

	@property
	def fptr(self):
		"""fptr commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fptr'):
			from .Fptr import Fptr
			self._fptr = Fptr(self._core, self._base)
		return self._fptr

	@property
	def isin(self):
		"""isin commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_isin'):
			from .Isin import Isin
			self._isin = Isin(self._core, self._base)
		return self._isin

	@property
	def mcbGroups(self):
		"""mcbGroups commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcbGroups'):
			from .McbGroups import McbGroups
			self._mcbGroups = McbGroups(self._core, self._base)
		return self._mcbGroups

	@property
	def mcsTable(self):
		"""mcsTable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcsTable'):
			from .McsTable import McsTable
			self._mcsTable = McsTable(self._core, self._base)
		return self._mcsTable

	@property
	def mrank(self):
		"""mrank commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mrank'):
			from .Mrank import Mrank
			self._mrank = Mrank(self._core, self._base)
		return self._mrank

	@property
	def mttPrecoding(self):
		"""mttPrecoding commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mttPrecoding'):
			from .MttPrecoding import MttPrecoding
			self._mttPrecoding = MttPrecoding(self._core, self._base)
		return self._mttPrecoding

	@property
	def oi01(self):
		"""oi01 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_oi01'):
			from .Oi01 import Oi01
			self._oi01 = Oi01(self._core, self._base)
		return self._oi01

	@property
	def olpc(self):
		"""olpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_olpc'):
			from .Olpc import Olpc
			self._olpc = Olpc(self._core, self._base)
		return self._olpc

	@property
	def pi01(self):
		"""pi01 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pi01'):
			from .Pi01 import Pi01
			self._pi01 = Pi01(self._core, self._base)
		return self._pi01

	@property
	def pi02(self):
		"""pi02 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pi02'):
			from .Pi02 import Pi02
			self._pi02 = Pi02(self._core, self._base)
		return self._pi02

	@property
	def ppsl(self):
		"""ppsl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ppsl'):
			from .Ppsl import Ppsl
			self._ppsl = Ppsl(self._core, self._base)
		return self._ppsl

	@property
	def rbgSize(self):
		"""rbgSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbgSize'):
			from .RbgSize import RbgSize
			self._rbgSize = RbgSize(self._core, self._base)
		return self._rbgSize

	@property
	def resAlloc(self):
		"""resAlloc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_resAlloc'):
			from .ResAlloc import ResAlloc
			self._resAlloc = ResAlloc(self._core, self._base)
		return self._resAlloc

	@property
	def scrambling(self):
		"""scrambling commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_scrambling'):
			from .Scrambling import Scrambling
			self._scrambling = Scrambling(self._core, self._base)
		return self._scrambling

	@property
	def t1Gran(self):
		"""t1Gran commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_t1Gran'):
			from .T1Gran import T1Gran
			self._t1Gran = T1Gran(self._core, self._base)
		return self._t1Gran

	@property
	def tpState(self):
		"""tpState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpState'):
			from .TpState import TpState
			self._tpState = TpState(self._core, self._base)
		return self._tpState

	@property
	def txConfig(self):
		"""txConfig commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_txConfig'):
			from .TxConfig import TxConfig
			self._txConfig = TxConfig(self._core, self._base)
		return self._txConfig

	@property
	def uitl(self):
		"""uitl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uitl'):
			from .Uitl import Uitl
			self._uitl = Uitl(self._core, self._base)
		return self._uitl

	def clone(self) -> 'Pusch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pusch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Up:
	"""Up commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("up", core, parent)

	def set(self, up: float, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:ENHanced:CHANnel<CH0>:DPCH:DPControl:RANGe:UP \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.range.up.set(up = 1.0, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command selects the dynamic range for ranging down the channel power. \n
			:param up: float Range: 0 to 60, Unit: dB
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.decimal_value_to_str(up)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:RANGe:UP {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:ENHanced:CHANnel<CH0>:DPCH:DPControl:RANGe:UP \n
		Snippet: value: float = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.range.up.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command selects the dynamic range for ranging down the channel power. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: up: No help available"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:RANGe:UP?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mrb:
	"""Mrb commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mrb", core, parent)

	def set(self, pucch_mrb: enums.NumbersC, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[SUBF<ST0>]:ALLoc<CH0>:PUCCh:MRB \n
		Snippet: driver.source.bb.eutra.uplink.subf.alloc.pucch.mrb.set(pucch_mrb = enums.NumbersC._1, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the number of resource blocks used by PUCCH format 5. \n
			:param pucch_mrb: 1| 2| 3| 4| 5| 6| 8
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.enum_scalar_to_str(pucch_mrb, enums.NumbersC)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUCCh:MRB {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default) -> enums.NumbersC:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:[SUBF<ST0>]:ALLoc<CH0>:PUCCh:MRB \n
		Snippet: value: enums.NumbersC = driver.source.bb.eutra.uplink.subf.alloc.pucch.mrb.get(subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		Sets the number of resource blocks used by PUCCH format 5. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: pucch_mrb: 1| 2| 3| 4| 5| 6| 8"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUCCh:MRB?')
		return Conversions.str_to_scalar_enum(response, enums.NumbersC)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Prbs:
	"""Prbs commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("prbs", core, parent)

	# noinspection PyTypeChecker
	def get_length(self) -> enums.DmDataPrbs:
		"""SCPI: [SOURce<HW>]:BB:DM:PRBS:[LENGth] \n
		Snippet: value: enums.DmDataPrbs = driver.source.bb.dm.prbs.get_length() \n
		Defines the length of the pseudo-random sequence in accordance with the following equation: Length = (2^Length) - 1 \n
			:return: length: 9| 11| 15| 16| 20| 21| 23| PN9| PN11| PN15| PN16| PN20| PN21| PN23
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DM:PRBS:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.DmDataPrbs)

	def set_length(self, length: enums.DmDataPrbs) -> None:
		"""SCPI: [SOURce<HW>]:BB:DM:PRBS:[LENGth] \n
		Snippet: driver.source.bb.dm.prbs.set_length(length = enums.DmDataPrbs._11) \n
		Defines the length of the pseudo-random sequence in accordance with the following equation: Length = (2^Length) - 1 \n
			:param length: 9| 11| 15| 16| 20| 21| 23| PN9| PN11| PN15| PN16| PN20| PN21| PN23
		"""
		param = Conversions.enum_scalar_to_str(length, enums.DmDataPrbs)
		self._core.io.write(f'SOURce<HwInstance>:BB:DM:PRBS:LENGth {param}')



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MaOffset:
	"""MaOffset commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("maOffset", core, parent)

	@property
	def nmOffset(self):
		"""nmOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nmOffset'):
			from .NmOffset import NmOffset
			self._nmOffset = NmOffset(self._core, self._base)
		return self._nmOffset

	@property
	def val(self):
		"""val commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_val'):
			from .Val import Val
			self._val = Val(self._core, self._base)
		return self._val

	def clone(self) -> 'MaOffset':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MaOffset(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tap:
	"""Tap commands group definition. 377 total commands, 5 Sub-groups, 1 group commands
	Repeated Capability: MimoTap, default value after init: MimoTap.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tap", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_mimoTap_get', 'repcap_mimoTap_set', repcap.MimoTap.Nr1)

	def repcap_mimoTap_set(self, enum_value: repcap.MimoTap) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to MimoTap.Default
		Default value after init: MimoTap.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_mimoTap_get(self) -> repcap.MimoTap:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def antenna(self):
		"""antenna commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import Antenna
			self._antenna = Antenna(self._core, self._base)
		return self._antenna

	@property
	def gvector(self):
		"""gvector commands group. 66 Sub-classes, 1 commands."""
		if not hasattr(self, '_gvector'):
			from .Gvector import Gvector
			self._gvector = Gvector(self._core, self._base)
		return self._gvector

	@property
	def kronecker(self):
		"""kronecker commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_kronecker'):
			from .Kronecker import Kronecker
			self._kronecker = Kronecker(self._core, self._base)
		return self._kronecker

	@property
	def matrix(self):
		"""matrix commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_matrix'):
			from .Matrix import Matrix
			self._matrix = Matrix(self._core, self._base)
		return self._matrix

	@property
	def tgn(self):
		"""tgn commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tgn'):
			from .Tgn import Tgn
			self._tgn = Tgn(self._core, self._base)
		return self._tgn

	# noinspection PyTypeChecker
	def get_value(self) -> enums.FadMimoTap:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP \n
		Snippet: value: enums.FadMimoTap = driver.source.fsimulator.mimo.tap.get_value() \n
		Sets the current tap. \n
			:return: tap: TAP1| TAP2| TAP3| TAP4| TAP5| TAP6| TAP7| TAP8| TAP9| TAP10| TAP11| TAP12| TAP13| TAP14| TAP15| TAP16| TAP17| TAP18| TAP19| TAP20
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:MIMO:TAP?')
		return Conversions.str_to_scalar_enum(response, enums.FadMimoTap)

	def set_value(self, tap: enums.FadMimoTap) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:MIMO:TAP \n
		Snippet: driver.source.fsimulator.mimo.tap.set_value(tap = enums.FadMimoTap.TAP1) \n
		Sets the current tap. \n
			:param tap: TAP1| TAP2| TAP3| TAP4| TAP5| TAP6| TAP7| TAP8| TAP9| TAP10| TAP11| TAP12| TAP13| TAP14| TAP15| TAP16| TAP17| TAP18| TAP19| TAP20
		"""
		param = Conversions.enum_scalar_to_str(tap, enums.FadMimoTap)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:MIMO:TAP {param}')

	def clone(self) -> 'Tap':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tap(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sinterval:
	"""Sinterval commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sinterval", core, parent)

	def set(self, user_sps_int: enums.SpsInt, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:USER<CH>:SPS:SINTerval \n
		Snippet: driver.source.bb.oneweb.downlink.user.sps.sinterval.set(user_sps_int = enums.SpsInt.S10, userIx = repcap.UserIx.Default) \n
		No command help available \n
			:param user_sps_int: No help available
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.enum_scalar_to_str(user_sps_int, enums.SpsInt)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:DL:USER{userIx_cmd_val}:SPS:SINTerval {param}')

	# noinspection PyTypeChecker
	def get(self, userIx=repcap.UserIx.Default) -> enums.SpsInt:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:USER<CH>:SPS:SINTerval \n
		Snippet: value: enums.SpsInt = driver.source.bb.oneweb.downlink.user.sps.sinterval.get(userIx = repcap.UserIx.Default) \n
		No command help available \n
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: user_sps_int: No help available"""
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:DL:USER{userIx_cmd_val}:SPS:SINTerval?')
		return Conversions.str_to_scalar_enum(response, enums.SpsInt)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpdch:
	"""Dpdch commands group definition. 5 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpdch", core, parent)

	@property
	def ccode(self):
		"""ccode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccode'):
			from .Ccode import Ccode
			self._ccode = Ccode(self._core, self._base)
		return self._ccode

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._base)
		return self._symbolRate

	def clone(self) -> 'Dpdch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dpdch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rms:
	"""Rms commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rms", core, parent)

	def get(self, channelNull=repcap.ChannelNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BBIN:CHANnel<CH0>:POWer:RMS \n
		Snippet: value: float = driver.source.bbin.channel.power.rms.get(channelNull = repcap.ChannelNull.Default) \n
		Queries the estimated RMS level. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: bbin_iq_hs_ch_po_rms: float Range: -100 to 10"""
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BBIN:CHANnel{channelNull_cmd_val}:POWer:RMS?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sgamma:
	"""Sgamma commands group definition. 5 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sgamma", core, parent)

	@property
	def magnitude(self):
		"""magnitude commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_magnitude'):
			from .Magnitude import Magnitude
			self._magnitude = Magnitude(self._core, self._base)
		return self._magnitude

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import Phase
			self._phase = Phase(self._core, self._base)
		return self._phase

	def delete(self) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:DATA:SGAMma:DELete \n
		Snippet: driver.source.correction.cset.data.sgamma.delete() \n
		No command help available \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:CORRection:CSET:DATA:SGAMma:DELete')

	def delete_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:CSET:DATA:SGAMma:DELete \n
		Snippet: driver.source.correction.cset.data.sgamma.delete_with_opc() \n
		No command help available \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:CORRection:CSET:DATA:SGAMma:DELete')

	def clone(self) -> 'Sgamma':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sgamma(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, baseStation=repcap.BaseStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:SCPich:PREFerence:[STATe] \n
		Snippet: driver.source.bb.w3Gpp.bstation.scpich.preference.state.set(state = False, baseStation = repcap.BaseStation.Default) \n
		The command activates or deactivates the use of S-CPICH as reference phase. \n
			:param state: ON| OFF
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')"""
		param = Conversions.bool_to_str(state)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:SCPich:PREFerence:STATe {param}')

	def get(self, baseStation=repcap.BaseStation.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:SCPich:PREFerence:[STATe] \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.scpich.preference.state.get(baseStation = repcap.BaseStation.Default) \n
		The command activates or deactivates the use of S-CPICH as reference phase. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:return: state: ON| OFF"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:SCPich:PREFerence:STATe?')
		return Conversions.str_to_bool(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.EnhHsHarqMode, cell=repcap.Cell.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:HSUPA:HARQ:MODE \n
		Snippet: driver.source.bb.tdscdma.up.cell.enh.dch.hsupa.harq.mode.set(mode = enums.EnhHsHarqMode.CACK, cell = repcap.Cell.Default) \n
		Sets the HARQ simulation mode. \n
			:param mode: CACK| CNACk CACK New data is used for each new TTI. This mode is used to simulate maximum throughput transmission. CNACk Enables NACK simulation, i.e. depending on the sequence selected with command BB:TDSC:DOWN:CELL1:ENH:DCH:HSDPA:RVS packets are retransmitted. This mode is used for testing with varying redundancy version.
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')"""
		param = Conversions.enum_scalar_to_str(mode, enums.EnhHsHarqMode)
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:HSUPA:HARQ:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default) -> enums.EnhHsHarqMode:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:ENH:DCH:HSUPA:HARQ:MODE \n
		Snippet: value: enums.EnhHsHarqMode = driver.source.bb.tdscdma.up.cell.enh.dch.hsupa.harq.mode.get(cell = repcap.Cell.Default) \n
		Sets the HARQ simulation mode. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:return: mode: CACK| CNACk CACK New data is used for each new TTI. This mode is used to simulate maximum throughput transmission. CNACk Enables NACK simulation, i.e. depending on the sequence selected with command BB:TDSC:DOWN:CELL1:ENH:DCH:HSDPA:RVS packets are retransmitted. This mode is used for testing with varying redundancy version."""
		cell_cmd_val = self._base.get_repcap_cmd_value(cell, repcap.Cell)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:ENH:DCH:HSUPA:HARQ:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EnhHsHarqMode)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Gap:
	"""Gap commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gap", core, parent)

	def set(self, gap: bool, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:GAP \n
		Snippet: driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.item.dciConf.gap.set(gap = False, subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI Format 1A/1B/1C/1D field GAP value. \n
			:param gap: ON| OFF
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')"""
		param = Conversions.bool_to_str(gap)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:GAP {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:DCIConf:GAP \n
		Snippet: value: bool = driver.source.bb.eutra.downlink.subf.encc.pdcch.extc.item.dciConf.gap.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Sets the DCI Format 1A/1B/1C/1D field GAP value. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: gap: ON| OFF"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:DCIConf:GAP?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	def get_loss(self) -> float:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:POWer:LOSS \n
		Snippet: value: float = driver.source.regenerator.radar.power.get_loss() \n
		Additional loss to compensate for system or cable loss. \n
			:return: power_loss: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:RADar:POWer:LOSS?')
		return Conversions.str_to_float(response)

	def set_loss(self, power_loss: float) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:POWer:LOSS \n
		Snippet: driver.source.regenerator.radar.power.set_loss(power_loss = 1.0) \n
		Additional loss to compensate for system or cable loss. \n
			:param power_loss: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(power_loss)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:RADar:POWer:LOSS {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.RegRadarPowSett:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:POWer:MODE \n
		Snippet: value: enums.RegRadarPowSett = driver.source.regenerator.radar.power.get_mode() \n
		Sets how the radar receive power is calculated. \n
			:return: mode: REQuation| MANual
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:RADar:POWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.RegRadarPowSett)

	def set_mode(self, mode: enums.RegRadarPowSett) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:POWer:MODE \n
		Snippet: driver.source.regenerator.radar.power.set_mode(mode = enums.RegRadarPowSett.MANual) \n
		Sets how the radar receive power is calculated. \n
			:param mode: REQuation| MANual
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.RegRadarPowSett)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:RADar:POWer:MODE {param}')

	def get_tx(self) -> float:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:POWer:TX \n
		Snippet: value: float = driver.source.regenerator.radar.power.get_tx() \n
		Sets the radar transmit power PTx. \n
			:return: power: float Range: -50 to 100
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:RADar:POWer:TX?')
		return Conversions.str_to_float(response)

	def set_tx(self, power: float) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:RADar:POWer:TX \n
		Snippet: driver.source.regenerator.radar.power.set_tx(power = 1.0) \n
		Sets the radar transmit power PTx. \n
			:param power: float Range: -50 to 100
		"""
		param = Conversions.decimal_value_to_str(power)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:RADar:POWer:TX {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Wlnn:
	"""Wlnn commands group definition. 297 total commands, 9 Sub-groups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("wlnn", core, parent)

	@property
	def antenna(self):
		"""antenna commands group. 1 Sub-classes, 4 commands."""
		if not hasattr(self, '_antenna'):
			from .Antenna import Antenna
			self._antenna = Antenna(self._core, self._base)
		return self._antenna

	@property
	def clipping(self):
		"""clipping commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clipping'):
			from .Clipping import Clipping
			self._clipping = Clipping(self._core, self._base)
		return self._clipping

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import Clock
			self._clock = Clock(self._core, self._base)
		return self._clock

	@property
	def fblock(self):
		"""fblock commands group. 63 Sub-classes, 2 commands."""
		if not hasattr(self, '_fblock'):
			from .Fblock import Fblock
			self._fblock = Fblock(self._core, self._base)
		return self._fblock

	@property
	def filterPy(self):
		"""filterPy commands group. 4 Sub-classes, 2 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import Setting
			self._setting = Setting(self._core, self._base)
		return self._setting

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._base)
		return self._symbolRate

	@property
	def trigger(self):
		"""trigger commands group. 5 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import Trigger
			self._trigger = Trigger(self._core, self._base)
		return self._trigger

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import Waveform
			self._waveform = Waveform(self._core, self._base)
		return self._waveform

	# noinspection PyTypeChecker
	def get_bandwidth(self) -> enums.WlannTxBw:
		"""SCPI: [SOURce<HW>]:BB:WLNN:BWidth \n
		Snippet: value: enums.WlannTxBw = driver.source.bb.wlnn.get_bandwidth() \n
		The command selects the transmission bandwidth. Whenever the bandwidth changes from a higher to a lower one, the frame
		blocks are validated because some of them could be invalid in the lower bandwidth (invalid TX Mode) . \n
			:return: bwidth: BW20| BW40| BW80| BW160| BW320 Unit: MHz
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:BWidth?')
		return Conversions.str_to_scalar_enum(response, enums.WlannTxBw)

	def set_bandwidth(self, bwidth: enums.WlannTxBw) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:BWidth \n
		Snippet: driver.source.bb.wlnn.set_bandwidth(bwidth = enums.WlannTxBw.BW160) \n
		The command selects the transmission bandwidth. Whenever the bandwidth changes from a higher to a lower one, the frame
		blocks are validated because some of them could be invalid in the lower bandwidth (invalid TX Mode) . \n
			:param bwidth: BW20| BW40| BW80| BW160| BW320 Unit: MHz
		"""
		param = Conversions.enum_scalar_to_str(bwidth, enums.WlannTxBw)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:BWidth {param}')

	def set_cf_block(self, cf_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:CFBLock \n
		Snippet: driver.source.bb.wlnn.set_cf_block(cf_block = 1) \n
		Copies the selected frame block. \n
			:param cf_block: integer Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(cf_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:CFBLock {param}')

	def set_df_block(self, df_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:DFBLock \n
		Snippet: driver.source.bb.wlnn.set_df_block(df_block = 1) \n
		Deletes the selected frame block. \n
			:param df_block: integer Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(df_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:DFBLock {param}')

	def set_if_block(self, if_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:IFBLock \n
		Snippet: driver.source.bb.wlnn.set_if_block(if_block = 1) \n
		The command adds a default frame block before the selected frame block. \n
			:param if_block: No help available
		"""
		param = Conversions.decimal_value_to_str(if_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:IFBLock {param}')

	def set_pf_block(self, pf_block: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:PFBLock \n
		Snippet: driver.source.bb.wlnn.set_pf_block(pf_block = 1) \n
		Pastes the selected frame block. \n
			:param pf_block: integer Range: 1 to 99
		"""
		param = Conversions.decimal_value_to_str(pf_block)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:PFBLock {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:PRESet \n
		Snippet: driver.source.bb.wlnn.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command method RsSmw.Source.Bb.Wlnn.state. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:PRESet \n
		Snippet: driver.source.bb.wlnn.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command method RsSmw.Source.Bb.Wlnn.state. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:WLNN:PRESet')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLNN:STATe \n
		Snippet: value: bool = driver.source.bb.wlnn.get_state() \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:STATe \n
		Snippet: driver.source.bb.wlnn.set_state(state = False) \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:STATe {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:VERSion \n
		Snippet: value: str = driver.source.bb.wlnn.get_version() \n
		Queries the version of the IEEE 802.11 WLAN standard underlying the definitions. \n
			:return: version: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLNN:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'Wlnn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Wlnn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pbrate:
	"""Pbrate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pbrate", core, parent)

	def set(self, playback_rate: int, rowNull=repcap.RowNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:BBConf:ROW<CH0>:PBRate \n
		Snippet: driver.source.bb.nr5G.output.bbConf.row.pbrate.set(playback_rate = 1, rowNull = repcap.RowNull.Default) \n
		For [:SOURce<hw>]:BB:NR5G:OUTPut:BBConf:ROW<ch0>:VARiation 1, sets the playback speed. \n
			:param playback_rate: integer Per default, the playback rate is the same as the calculated sample rate but the value range also depends on the installed options. Range: 0 to 24e8
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')"""
		param = Conversions.decimal_value_to_str(playback_rate)
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:OUTPut:BBConf:ROW{rowNull_cmd_val}:PBRate {param}')

	def get(self, rowNull=repcap.RowNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:OUTPut:BBConf:ROW<CH0>:PBRate \n
		Snippet: value: int = driver.source.bb.nr5G.output.bbConf.row.pbrate.get(rowNull = repcap.RowNull.Default) \n
		For [:SOURce<hw>]:BB:NR5G:OUTPut:BBConf:ROW<ch0>:VARiation 1, sets the playback speed. \n
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
			:return: playback_rate: integer Per default, the playback rate is the same as the calculated sample rate but the value range also depends on the installed options. Range: 0 to 24e8"""
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:OUTPut:BBConf:ROW{rowNull_cmd_val}:PBRate?')
		return Conversions.str_to_int(response)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ds:
	"""Ds commands group definition. 9 total commands, 0 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ds", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:CATalog \n
		Snippet: value: List[str] = driver.source.bb.stereo.ds.get_catalog() \n
		No command help available \n
			:return: catalog: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:CATalog?')
		return Conversions.str_to_str_list(response)

	def get_deviation(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:DEViation \n
		Snippet: value: int = driver.source.bb.stereo.ds.get_deviation() \n
		No command help available \n
			:return: deviation: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:DEViation?')
		return Conversions.str_to_int(response)

	def set_deviation(self, deviation: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:DEViation \n
		Snippet: driver.source.bb.stereo.ds.set_deviation(deviation = 1) \n
		No command help available \n
			:param deviation: No help available
		"""
		param = Conversions.decimal_value_to_str(deviation)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:DEViation {param}')

	def get_drate(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:DRATe \n
		Snippet: value: float = driver.source.bb.stereo.ds.get_drate() \n
		No command help available \n
			:return: drate: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:DRATe?')
		return Conversions.str_to_float(response)

	def set_dselect(self, dselect: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:DSELect \n
		Snippet: driver.source.bb.stereo.ds.set_dselect(dselect = '1') \n
		No command help available \n
			:param dselect: No help available
		"""
		param = Conversions.value_to_quoted_str(dselect)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:DSELect {param}')

	# noinspection PyTypeChecker
	def get_dset(self) -> enums.FmStereoRdsRbdsCfgDataSource:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:DSET \n
		Snippet: value: enums.FmStereoRdsRbdsCfgDataSource = driver.source.bb.stereo.ds.get_dset() \n
		No command help available \n
			:return: dset: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:DSET?')
		return Conversions.str_to_scalar_enum(response, enums.FmStereoRdsRbdsCfgDataSource)

	def set_dset(self, dset: enums.FmStereoRdsRbdsCfgDataSource) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:DSET \n
		Snippet: driver.source.bb.stereo.ds.set_dset(dset = enums.FmStereoRdsRbdsCfgDataSource.GRPList) \n
		No command help available \n
			:param dset: No help available
		"""
		param = Conversions.enum_scalar_to_str(dset, enums.FmStereoRdsRbdsCfgDataSource)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:DSET {param}')

	# noinspection PyTypeChecker
	def get_gim(self) -> enums.FmStereoRdsRbdsCfgUsrGrpBeh:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:GIM \n
		Snippet: value: enums.FmStereoRdsRbdsCfgUsrGrpBeh = driver.source.bb.stereo.ds.get_gim() \n
		No command help available \n
			:return: gim: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:GIM?')
		return Conversions.str_to_scalar_enum(response, enums.FmStereoRdsRbdsCfgUsrGrpBeh)

	def set_gim(self, gim: enums.FmStereoRdsRbdsCfgUsrGrpBeh) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:GIM \n
		Snippet: driver.source.bb.stereo.ds.set_gim(gim = enums.FmStereoRdsRbdsCfgUsrGrpBeh.HEXFormat) \n
		No command help available \n
			:param gim: No help available
		"""
		param = Conversions.enum_scalar_to_str(gim, enums.FmStereoRdsRbdsCfgUsrGrpBeh)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:GIM {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FmStereoCfgMode:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:MODE \n
		Snippet: value: enums.FmStereoCfgMode = driver.source.bb.stereo.ds.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FmStereoCfgMode)

	def set_mode(self, mode: enums.FmStereoCfgMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:MODE \n
		Snippet: driver.source.bb.stereo.ds.set_mode(mode = enums.FmStereoCfgMode.RBDS) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.FmStereoCfgMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:MODE {param}')

	def get_phase(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:PHASe \n
		Snippet: value: float = driver.source.bb.stereo.ds.get_phase() \n
		No command help available \n
			:return: phase: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:PHASe?')
		return Conversions.str_to_float(response)

	def set_phase(self, phase: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:PHASe \n
		Snippet: driver.source.bb.stereo.ds.set_phase(phase = 1.0) \n
		No command help available \n
			:param phase: No help available
		"""
		param = Conversions.decimal_value_to_str(phase)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:PHASe {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:STATe \n
		Snippet: value: bool = driver.source.bb.stereo.ds.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:STEReo:DS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:DS:STATe \n
		Snippet: driver.source.bb.stereo.ds.set_state(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:DS:STATe {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	def get(self, channelNull=repcap.ChannelNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:[POWer] \n
		Snippet: value: float = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.power.get(channelNull = repcap.ChannelNull.Default) \n
		The command queries the deviation of the channel power (delta POW) from the set power start value of the corresponding
		enhanced channels. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: power: float Range: -60 to 60"""
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:POWer?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Hostname:
	"""Hostname commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("hostname", core, parent)

	def get(self, sequencer=repcap.Sequencer.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:[SEQuencer<ST>]:NETWork:HOSTname \n
		Snippet: value: str = driver.source.bb.esequencer.rtci.sequencer.network.hostname.get(sequencer = repcap.Sequencer.Default) \n
		Sets an individual hostname for the R&S SMW. Note:We recommend that you do not change the hostname to avoid problems with
		the network connection. If you change the hostname, be sure to use a unique name. This is a password-protected function.
		Unlock the protection level 1 to access it, see method RsSmw.System.Protect.State.set. \n
			:param sequencer: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sequencer')
			:return: hostname: string"""
		sequencer_cmd_val = self._base.get_repcap_cmd_value(sequencer, repcap.Sequencer)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ESEQuencer:RTCI:SEQuencer{sequencer_cmd_val}:NETWork:HOSTname?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HaPattern:
	"""HaPattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("haPattern", core, parent)

	def set(self, ha_pattern: str, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:DPCCh:HS:HAPattern \n
		Snippet: driver.source.bb.w3Gpp.mstation.dpcch.hs.haPattern.set(ha_pattern = '1', mobileStation = repcap.MobileStation.Default) \n
		(Up to Release 7) The command enters the pattern for the HARQ-ACK field (Hybrid-ARQ Acknowledgement) . One bit is used
		per HS-DPCCH packet. \n
			:param ha_pattern: string The pattern is entered as string, the maximum number of entries is 32. Three different characters are permitted. 1 The HARQ ACK is sent (ACK) . Transmission was successful and correct. 0 The NACK is sent (NACK) . Transmission was not correct. With an NACK, the UE requests retransmission of the incorrect data. - Nothing is sent. Transmission is interrupted (Discontinuous Transmission, DTX) .
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.value_to_quoted_str(ha_pattern)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:DPCCh:HS:HAPattern {param}')

	def get(self, mobileStation=repcap.MobileStation.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:DPCCh:HS:HAPattern \n
		Snippet: value: str = driver.source.bb.w3Gpp.mstation.dpcch.hs.haPattern.get(mobileStation = repcap.MobileStation.Default) \n
		(Up to Release 7) The command enters the pattern for the HARQ-ACK field (Hybrid-ARQ Acknowledgement) . One bit is used
		per HS-DPCCH packet. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: ha_pattern: string The pattern is entered as string, the maximum number of entries is 32. Three different characters are permitted. 1 The HARQ ACK is sent (ACK) . Transmission was successful and correct. 0 The NACK is sent (NACK) . Transmission was not correct. With an NACK, the UE requests retransmission of the incorrect data. - Nothing is sent. Transmission is interrupted (Discontinuous Transmission, DTX) ."""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:DPCCh:HS:HAPattern?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Phich:
	"""Phich commands group definition. 6 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("phich", core, parent)

	@property
	def anPattern(self):
		"""anPattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_anPattern'):
			from .AnPattern import AnPattern
			self._anPattern = AnPattern(self._core, self._base)
		return self._anPattern

	@property
	def cell(self):
		"""cell commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_cell'):
			from .Cell import Cell
			self._cell = Cell(self._core, self._base)
		return self._cell

	@property
	def pmode(self):
		"""pmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmode'):
			from .Pmode import Pmode
			self._pmode = Pmode(self._core, self._base)
		return self._pmode

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	def clone(self) -> 'Phich':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Phich(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, gnssPsRandomNumberNull=repcap.GnssPsRandomNumberNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:SBAS:WAAS:NMESsage:NAV:PRN<CH>:STATe \n
		Snippet: driver.source.bb.gnss.system.sbas.waas.nmessage.nav.prNoise.state.set(state = False, gnssPsRandomNumberNull = repcap.GnssPsRandomNumberNull.Default) \n
		Enables an SV ID/ SV PRN. \n
			:param state: 0| 1| OFF| ON
			:param gnssPsRandomNumberNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'PrNoise')"""
		param = Conversions.bool_to_str(state)
		gnssPsRandomNumberNull_cmd_val = self._base.get_repcap_cmd_value(gnssPsRandomNumberNull, repcap.GnssPsRandomNumberNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SYSTem:SBAS:WAAS:NMESsage:NAV:PRN{gnssPsRandomNumberNull_cmd_val}:STATe {param}')

	def get(self, gnssPsRandomNumberNull=repcap.GnssPsRandomNumberNull.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:SBAS:WAAS:NMESsage:NAV:PRN<CH>:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.system.sbas.waas.nmessage.nav.prNoise.state.get(gnssPsRandomNumberNull = repcap.GnssPsRandomNumberNull.Default) \n
		Enables an SV ID/ SV PRN. \n
			:param gnssPsRandomNumberNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'PrNoise')
			:return: state: 0| 1| OFF| ON"""
		gnssPsRandomNumberNull_cmd_val = self._base.get_repcap_cmd_value(gnssPsRandomNumberNull, repcap.GnssPsRandomNumberNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SYSTem:SBAS:WAAS:NMESsage:NAV:PRN{gnssPsRandomNumberNull_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	def set(self, power: float, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:POWer \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.power.set(power = 1.0, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the channel power relative to the powers of the other channels. This setting also determines the starting power of
		the channel for Misuse TPC, Dynamic Power Control and the power control sequence simulation of OCNS mode 3i channels.
		With the command method RsSmw.Source.Bb.W3Gpp.Power.Adjust.set, the power of all the activated channels is adapted so
		that the total power corresponds to 0 dB. This does not change the power ratio among the individual channels. \n
			:param power: float Range: -80 to 0
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.decimal_value_to_str(power)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:POWer {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:POWer \n
		Snippet: value: float = driver.source.bb.w3Gpp.bstation.channel.power.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		Sets the channel power relative to the powers of the other channels. This setting also determines the starting power of
		the channel for Misuse TPC, Dynamic Power Control and the power control sequence simulation of OCNS mode 3i channels.
		With the command method RsSmw.Source.Bb.W3Gpp.Power.Adjust.set, the power of all the activated channels is adapted so
		that the total power corresponds to 0 dB. This does not change the power ratio among the individual channels. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: power: float Range: -80 to 0"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:POWer?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Level:
	"""Level commands group definition. 10 total commands, 4 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("level", core, parent)

	@property
	def attenuator(self):
		"""attenuator commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_attenuator'):
			from .Attenuator import Attenuator
			self._attenuator = Attenuator(self._core, self._base)
		return self._attenuator

	@property
	def haccuracy(self):
		"""haccuracy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_haccuracy'):
			from .Haccuracy import Haccuracy
			self._haccuracy = Haccuracy(self._core, self._base)
		return self._haccuracy

	@property
	def opu(self):
		"""opu commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_opu'):
			from .Opu import Opu
			self._opu = Opu(self._core, self._base)
		return self._opu

	@property
	def measure(self):
		"""measure commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_measure'):
			from .Measure import Measure
			self._measure = Measure(self._core, self._base)
		return self._measure

	# noinspection PyTypeChecker
	def get_bandwidth(self) -> enums.CalPowBandwidth:
		"""SCPI: CALibration<HW>:LEVel:BWIDth \n
		Snippet: value: enums.CalPowBandwidth = driver.calibration.level.get_bandwidth() \n
		No command help available \n
			:return: bandwidth: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:BWIDth?')
		return Conversions.str_to_scalar_enum(response, enums.CalPowBandwidth)

	def set_bandwidth(self, bandwidth: enums.CalPowBandwidth) -> None:
		"""SCPI: CALibration<HW>:LEVel:BWIDth \n
		Snippet: driver.calibration.level.set_bandwidth(bandwidth = enums.CalPowBandwidth.AUTO) \n
		No command help available \n
			:param bandwidth: No help available
		"""
		param = Conversions.enum_scalar_to_str(bandwidth, enums.CalPowBandwidth)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:BWIDth {param}')

	# noinspection PyTypeChecker
	def get_det_att(self) -> enums.DetAtt:
		"""SCPI: CALibration<HW>:LEVel:DETatt \n
		Snippet: value: enums.DetAtt = driver.calibration.level.get_det_att() \n
		No command help available \n
			:return: det_att: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:DETatt?')
		return Conversions.str_to_scalar_enum(response, enums.DetAtt)

	def set_det_att(self, det_att: enums.DetAtt) -> None:
		"""SCPI: CALibration<HW>:LEVel:DETatt \n
		Snippet: driver.calibration.level.set_det_att(det_att = enums.DetAtt.HIGH) \n
		No command help available \n
			:param det_att: No help available
		"""
		param = Conversions.enum_scalar_to_str(det_att, enums.DetAtt)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:DETatt {param}')

	def get_local(self) -> bool:
		"""SCPI: CALibration<HW>:LEVel:LOCal \n
		Snippet: value: bool = driver.calibration.level.get_local() \n
		No command help available \n
			:return: result: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:LOCal?')
		return Conversions.str_to_bool(response)

	# noinspection PyTypeChecker
	def get_state(self) -> enums.StateExtended:
		"""SCPI: CALibration<HW>:LEVel:STATe \n
		Snippet: value: enums.StateExtended = driver.calibration.level.get_state() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('CALibration<HwInstance>:LEVel:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.StateExtended)

	def set_state(self, state: enums.StateExtended) -> None:
		"""SCPI: CALibration<HW>:LEVel:STATe \n
		Snippet: driver.calibration.level.set_state(state = enums.StateExtended._0) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.enum_scalar_to_str(state, enums.StateExtended)
		self._core.io.write(f'CALibration<HwInstance>:LEVel:STATe {param}')

	def clone(self) -> 'Level':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Level(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Execute:
	"""Execute commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("execute", core, parent)

	def set(self, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:MPATh:COPY:EXECute \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.mpath.copy.execute.set(vehicle = repcap.Vehicle.Default) \n
		Copies the multipath configuration of the source GNSS System and SV ID to the target SV ID and GNSS system or to all SV
		IDs from a system.
			INTRO_CMD_HELP: Set the source with: \n
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:SYSTem
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:SVID
			INTRO_CMD_HELP: Set the target with: \n
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:COPY:SYSTem
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:COPY:SVID \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')"""
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:MPATh:COPY:EXECute')

	def set_with_opc(self, vehicle=repcap.Vehicle.Default) -> None:
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:MPATh:COPY:EXECute \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.mpath.copy.execute.set_with_opc(vehicle = repcap.Vehicle.Default) \n
		Copies the multipath configuration of the source GNSS System and SV ID to the target SV ID and GNSS system or to all SV
		IDs from a system.
			INTRO_CMD_HELP: Set the source with: \n
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:SYSTem
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:SVID
			INTRO_CMD_HELP: Set the target with: \n
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:COPY:SYSTem
			- [:SOURce<hw>]:BB:GNSS:RECeiver[:V<st>]:ENVironment:MPATh:COPY:SVID \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:MPATh:COPY:EXECute')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vobs:
	"""Vobs commands group definition. 7 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("vobs", core, parent)

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_file'):
			from .File import File
			self._file = File(self._core, self._base)
		return self._file

	@property
	def morientation(self):
		"""morientation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_morientation'):
			from .Morientation import Morientation
			self._morientation = Morientation(self._core, self._base)
		return self._morientation

	@property
	def pmodel(self):
		"""pmodel commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmodel'):
			from .Pmodel import Pmodel
			self._pmodel = Pmodel(self._core, self._base)
		return self._pmodel

	@property
	def predefined(self):
		"""predefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_predefined'):
			from .Predefined import Predefined
			self._predefined = Predefined(self._core, self._base)
		return self._predefined

	@property
	def roffset(self):
		"""roffset commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_roffset'):
			from .Roffset import Roffset
			self._roffset = Roffset(self._core, self._base)
		return self._roffset

	def clone(self) -> 'Vobs':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Vobs(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sib:
	"""Sib commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sib", core, parent)

	def set(self, scheduling_sib_1: int, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:ALLoc<CH0>:CCODing:SIB \n
		Snippet: driver.source.bb.eutra.downlink.emtc.alloc.ccoding.sib.set(scheduling_sib_1 = 1, allocationNull = repcap.AllocationNull.Default) \n
		Sets the parameter schedulingInfoSIB1-RB and defines the PDSCH number of repetitions. Query the resulting number of
		repetitions with the command [:SOURce<hw>]:BB:EUTRa:DL:EMTC:ALLoc<ch0>:CCODing:RSIB?. \n
			:param scheduling_sib_1: integer Range: 0 to 18
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')"""
		param = Conversions.decimal_value_to_str(scheduling_sib_1)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:ALLoc{allocationNull_cmd_val}:CCODing:SIB {param}')

	def get(self, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:EMTC:ALLoc<CH0>:CCODing:SIB \n
		Snippet: value: int = driver.source.bb.eutra.downlink.emtc.alloc.ccoding.sib.get(allocationNull = repcap.AllocationNull.Default) \n
		Sets the parameter schedulingInfoSIB1-RB and defines the PDSCH number of repetitions. Query the resulting number of
		repetitions with the command [:SOURce<hw>]:BB:EUTRa:DL:EMTC:ALLoc<ch0>:CCODing:RSIB?. \n
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:return: scheduling_sib_1: integer Range: 0 to 18"""
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:EMTC:ALLoc{allocationNull_cmd_val}:CCODing:SIB?')
		return Conversions.str_to_int(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal.RepeatedCapability import RepeatedCapability
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cw:
	"""Cw commands group definition. 2 total commands, 2 Sub-groups, 0 group commands
	Repeated Capability: CodewordNull, default value after init: CodewordNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cw", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_codewordNull_get', 'repcap_codewordNull_set', repcap.CodewordNull.Nr0)

	def repcap_codewordNull_set(self, enum_value: repcap.CodewordNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CodewordNull.Default
		Default value after init: CodewordNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_codewordNull_get(self) -> repcap.CodewordNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def mod(self):
		"""mod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mod'):
			from .Mod import Mod
			self._mod = Mod(self._core, self._base)
		return self._mod

	@property
	def physBits(self):
		"""physBits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_physBits'):
			from .PhysBits import PhysBits
			self._physBits = PhysBits(self._core, self._base)
		return self._physBits

	def clone(self) -> 'Cw':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Cw(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Values:
	"""Values commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("values", core, parent)

	def set(self, values: List[str], terminal=repcap.Terminal.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:ACKChannel:VALues \n
		Snippet: driver.source.bb.evdo.terminal.ackChannel.values.set(values = ['raw1', 'raw2', 'raw3'], terminal = repcap.Terminal.Default) \n
		(enabled for access terminal working in traffic mode) Specifies the data pattern transmitted on the ACK Channel.
		The sequence starts at frame 0 and slot 0 and is repeated with the length of the pattern.A 0 specifies an ACK, a 1
		specifies a NAK. The pattern is only read for slots that are gated on. This parameter is in binary format and has a
		maximal length of 16 bits. \n
			:param values: integer
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')"""
		param = Conversions.list_to_csv_str(values)
		terminal_cmd_val = self._base.get_repcap_cmd_value(terminal, repcap.Terminal)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:ACKChannel:VALues {param}')

	def get(self, terminal=repcap.Terminal.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:EVDO:TERMinal<ST>:ACKChannel:VALues \n
		Snippet: value: List[str] = driver.source.bb.evdo.terminal.ackChannel.values.get(terminal = repcap.Terminal.Default) \n
		(enabled for access terminal working in traffic mode) Specifies the data pattern transmitted on the ACK Channel.
		The sequence starts at frame 0 and slot 0 and is repeated with the length of the pattern.A 0 specifies an ACK, a 1
		specifies a NAK. The pattern is only read for slots that are gated on. This parameter is in binary format and has a
		maximal length of 16 bits. \n
			:param terminal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Terminal')
			:return: values: integer"""
		terminal_cmd_val = self._base.get_repcap_cmd_value(terminal, repcap.Terminal)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EVDO:TERMinal{terminal_cmd_val}:ACKChannel:VALues?')
		return Conversions.str_to_str_list(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DumRes:
	"""DumRes commands group definition. 15 total commands, 12 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dumRes", core, parent)

	@property
	def apMap(self):
		"""apMap commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_apMap'):
			from .ApMap import ApMap
			self._apMap = ApMap(self._core, self._base)
		return self._apMap

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def dlist(self):
		"""dlist commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dlist'):
			from .Dlist import Dlist
			self._dlist = Dlist(self._core, self._base)
		return self._dlist

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import Modulation
			self._modulation = Modulation(self._core, self._base)
		return self._modulation

	@property
	def naps(self):
		"""naps commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_naps'):
			from .Naps import Naps
			self._naps = Naps(self._core, self._base)
		return self._naps

	@property
	def pattern(self):
		"""pattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pattern'):
			from .Pattern import Pattern
			self._pattern = Pattern(self._core, self._base)
		return self._pattern

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def prec(self):
		"""prec commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_prec'):
			from .Prec import Prec
			self._prec = Prec(self._core, self._base)
		return self._prec

	@property
	def scSpacing(self):
		"""scSpacing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scSpacing'):
			from .ScSpacing import ScSpacing
			self._scSpacing = ScSpacing(self._core, self._base)
		return self._scSpacing

	@property
	def sltFmt(self):
		"""sltFmt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sltFmt'):
			from .SltFmt import SltFmt
			self._sltFmt = SltFmt(self._core, self._base)
		return self._sltFmt

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def tpState(self):
		"""tpState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tpState'):
			from .TpState import TpState
			self._tpState = TpState(self._core, self._base)
		return self._tpState

	def clone(self) -> 'DumRes':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DumRes(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class QsControl:
	"""QsControl commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("qsControl", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:QSControl:STATe \n
		Snippet: value: bool = driver.source.bb.wlad.pconfig.mac.qsControl.get_state() \n
		Enables/disables the QoS control. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:QSControl:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:QSControl:STATe \n
		Snippet: driver.source.bb.wlad.pconfig.mac.qsControl.set_state(state = False) \n
		Enables/disables the QoS control. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:QSControl:STATe {param}')

	def get_value(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:QSControl \n
		Snippet: value: List[str] = driver.source.bb.wlad.pconfig.mac.qsControl.get_value() \n
		Sets the value for the QoS control field. \n
			:return: qs_control: 16 bits
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:QSControl?')
		return Conversions.str_to_str_list(response)

	def set_value(self, qs_control: List[str]) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLAD:PCONfig:MAC:QSControl \n
		Snippet: driver.source.bb.wlad.pconfig.mac.qsControl.set_value(qs_control = ['raw1', 'raw2', 'raw3']) \n
		Sets the value for the QoS control field. \n
			:param qs_control: 16 bits
		"""
		param = Conversions.list_to_csv_str(qs_control)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLAD:PCONfig:MAC:QSControl {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def set(self, waypoints: str, baseSt=repcap.BaseSt.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:BASE<ST>:LOCation:WAYPoints:FILE \n
		Snippet: driver.source.bb.gnss.rtk.base.location.waypoints.file.set(waypoints = '1', baseSt = repcap.BaseSt.Default) \n
		No command help available \n
			:param waypoints: No help available
			:param baseSt: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Base')"""
		param = Conversions.value_to_quoted_str(waypoints)
		baseSt_cmd_val = self._base.get_repcap_cmd_value(baseSt, repcap.BaseSt)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RTK:BASE{baseSt_cmd_val}:LOCation:WAYPoints:FILE {param}')

	def get(self, baseSt=repcap.BaseSt.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:BASE<ST>:LOCation:WAYPoints:FILE \n
		Snippet: value: str = driver.source.bb.gnss.rtk.base.location.waypoints.file.get(baseSt = repcap.BaseSt.Default) \n
		No command help available \n
			:param baseSt: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Base')
			:return: waypoints: No help available"""
		baseSt_cmd_val = self._base.get_repcap_cmd_value(baseSt, repcap.BaseSt)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RTK:BASE{baseSt_cmd_val}:LOCation:WAYPoints:FILE?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CmbSize:
	"""CmbSize commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cmbSize", core, parent)

	def set(self, prs_rs_comb_size: enums.PrsCombSize, cellNull=repcap.CellNull.Nr0, resourceSetNull=repcap.ResourceSetNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:PRS:RSET<ST0>:CMBSize \n
		Snippet: driver.source.bb.nr5G.node.cell.prs.rset.cmbSize.set(prs_rs_comb_size = enums.PrsCombSize.C12, cellNull = repcap.CellNull.Nr0, resourceSetNull = repcap.ResourceSetNull.Default) \n
		Sets the resource element (RE) spacing in each symbol of a resource within a resource set. \n
			:param prs_rs_comb_size: C2| C4| C6| C12
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param resourceSetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Rset')"""
		param = Conversions.enum_scalar_to_str(prs_rs_comb_size, enums.PrsCombSize)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		resourceSetNull_cmd_val = self._base.get_repcap_cmd_value(resourceSetNull, repcap.ResourceSetNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:PRS:RSET{resourceSetNull_cmd_val}:CMBSize {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Nr0, resourceSetNull=repcap.ResourceSetNull.Default) -> enums.PrsCombSize:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:PRS:RSET<ST0>:CMBSize \n
		Snippet: value: enums.PrsCombSize = driver.source.bb.nr5G.node.cell.prs.rset.cmbSize.get(cellNull = repcap.CellNull.Nr0, resourceSetNull = repcap.ResourceSetNull.Default) \n
		Sets the resource element (RE) spacing in each symbol of a resource within a resource set. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param resourceSetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Rset')
			:return: prs_rs_comb_size: C2| C4| C6| C12"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		resourceSetNull_cmd_val = self._base.get_repcap_cmd_value(resourceSetNull, repcap.ResourceSetNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:PRS:RSET{resourceSetNull_cmd_val}:CMBSize?')
		return Conversions.str_to_scalar_enum(response, enums.PrsCombSize)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Resolve:
	"""Resolve commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("resolve", core, parent)

	def set(self, baseStation=repcap.BaseStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:DCONflict:RESolve \n
		Snippet: driver.source.bb.w3Gpp.bstation.dconflict.resolve.set(baseStation = repcap.BaseStation.Default) \n
		The command resolves existing domain conflicts by modifying the Channelization Codes of the affected channels. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:DCONflict:RESolve')

	def set_with_opc(self, baseStation=repcap.BaseStation.Default) -> None:
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:DCONflict:RESolve \n
		Snippet: driver.source.bb.w3Gpp.bstation.dconflict.resolve.set_with_opc(baseStation = repcap.BaseStation.Default) \n
		The command resolves existing domain conflicts by modifying the Channelization Codes of the affected channels. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:DCONflict:RESolve')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sue:
	"""Sue commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sue", core, parent)

	def get_bb_selector(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:RTF:SUE:BBSelector \n
		Snippet: value: int = driver.source.bb.nr5G.tcw.rtf.sue.get_bb_selector() \n
		No command help available \n
			:return: suebb_selector: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:RTF:SUE:BBSelector?')
		return Conversions.str_to_int(response)

	def set_bb_selector(self, suebb_selector: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:RTF:SUE:BBSelector \n
		Snippet: driver.source.bb.nr5G.tcw.rtf.sue.set_bb_selector(suebb_selector = 1) \n
		No command help available \n
			:param suebb_selector: No help available
		"""
		param = Conversions.decimal_value_to_str(suebb_selector)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:RTF:SUE:BBSelector {param}')

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.FeedbackConnector:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:RTF:SUE:CONNector \n
		Snippet: value: enums.FeedbackConnector = driver.source.bb.nr5G.tcw.rtf.sue.get_connector() \n
		No command help available \n
			:return: sue_connector: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:TCW:RTF:SUE:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.FeedbackConnector)

	def set_connector(self, sue_connector: enums.FeedbackConnector) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:TCW:RTF:SUE:CONNector \n
		Snippet: driver.source.bb.nr5G.tcw.rtf.sue.set_connector(sue_connector = enums.FeedbackConnector.GLOBal) \n
		No command help available \n
			:param sue_connector: No help available
		"""
		param = Conversions.enum_scalar_to_str(sue_connector, enums.FeedbackConnector)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:TCW:RTF:SUE:CONNector {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tap:
	"""Tap commands group definition. 2 total commands, 2 Sub-groups, 0 group commands
	Repeated Capability: MimoTap, default value after init: MimoTap.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tap", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_mimoTap_get', 'repcap_mimoTap_set', repcap.MimoTap.Nr1)

	def repcap_mimoTap_set(self, enum_value: repcap.MimoTap) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to MimoTap.Default
		Default value after init: MimoTap.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_mimoTap_get(self) -> repcap.MimoTap:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def dot(self):
		"""dot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dot'):
			from .Dot import Dot
			self._dot = Dot(self._core, self._base)
		return self._dot

	@property
	def speed(self):
		"""speed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_speed'):
			from .Speed import Speed
			self._speed = Speed(self._core, self._base)
		return self._speed

	def clone(self) -> 'Tap':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tap(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Phy:
	"""Phy commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("phy", core, parent)

	@property
	def l1M(self):
		"""l1M commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_l1M'):
			from .L1M import L1M
			self._l1M = L1M(self._core, self._base)
		return self._l1M

	@property
	def l2M(self):
		"""l2M commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_l2M'):
			from .L2M import L2M
			self._l2M = L2M(self._core, self._base)
		return self._l2M

	@property
	def lcod(self):
		"""lcod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lcod'):
			from .Lcod import Lcod
			self._lcod = Lcod(self._core, self._base)
		return self._lcod

	def clone(self) -> 'Phy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Phy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bandwidth:
	"""Bandwidth commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bandwidth", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AutoManualMode:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:IQ:OPTimization:BANDwidth:MODE \n
		Snippet: value: enums.AutoManualMode = driver.source.correction.fresponse.iq.optimization.bandwidth.get_mode() \n
		No command help available \n
			:return: fr_resp_iq_opt_bw_mo: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:IQ:OPTimization:BANDwidth:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)

	def set_mode(self, fr_resp_iq_opt_bw_mo: enums.AutoManualMode) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:IQ:OPTimization:BANDwidth:MODE \n
		Snippet: driver.source.correction.fresponse.iq.optimization.bandwidth.set_mode(fr_resp_iq_opt_bw_mo = enums.AutoManualMode.AUTO) \n
		No command help available \n
			:param fr_resp_iq_opt_bw_mo: No help available
		"""
		param = Conversions.enum_scalar_to_str(fr_resp_iq_opt_bw_mo, enums.AutoManualMode)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:IQ:OPTimization:BANDwidth:MODE {param}')

	def get_value(self) -> int:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:IQ:OPTimization:BANDwidth:[VALue] \n
		Snippet: value: int = driver.source.correction.fresponse.iq.optimization.bandwidth.get_value() \n
		No command help available \n
			:return: fr_resp_iq_opt_bw_va: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:FRESponse:IQ:OPTimization:BANDwidth:VALue?')
		return Conversions.str_to_int(response)

	def set_value(self, fr_resp_iq_opt_bw_va: int) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:FRESponse:IQ:OPTimization:BANDwidth:[VALue] \n
		Snippet: driver.source.correction.fresponse.iq.optimization.bandwidth.set_value(fr_resp_iq_opt_bw_va = 1) \n
		No command help available \n
			:param fr_resp_iq_opt_bw_va: No help available
		"""
		param = Conversions.decimal_value_to_str(fr_resp_iq_opt_bw_va)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:FRESponse:IQ:OPTimization:BANDwidth:VALue {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Name:
	"""Name commands group definition. 12 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("name", core, parent)

	@property
	def auto(self):
		"""auto commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import Auto
			self._auto = Auto(self._core, self._base)
		return self._auto

	def get_value(self) -> str:
		"""SCPI: HCOPy:FILE:[NAME] \n
		Snippet: value: str = driver.hardCopy.file.name.get_value() \n
		Determines the file name and path to save the hard copy, provided automatic naming is disabled. Note: If you have enabled
		automatic naming, the instrument automatically generates the file name and directory, see 'Automatic Naming'. \n
			:return: name: string
		"""
		response = self._core.io.query_str('HCOPy:FILE:NAME?')
		return trim_str_response(response)

	def set_value(self, name: str) -> None:
		"""SCPI: HCOPy:FILE:[NAME] \n
		Snippet: driver.hardCopy.file.name.set_value(name = '1') \n
		Determines the file name and path to save the hard copy, provided automatic naming is disabled. Note: If you have enabled
		automatic naming, the instrument automatically generates the file name and directory, see 'Automatic Naming'. \n
			:param name: string
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'HCOPy:FILE:NAME {param}')

	def clone(self) -> 'Name':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Name(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
